@@ -1,7 +1,115 @@
 
-# $Id: makefile.r%v 3.38.2.134 1993/06/04 01:03:20 woo Exp woo $
+# $Id: makefile.r%v 3.50.1.17 1993/08/27 05:21:33 woo Exp woo $
 #
 # $Log: makefile.r%v $
+# Revision 3.50.1.17  1993/08/27  05:21:33  woo
+# V. Khera's fig patch
+#
+# Revision 3.50.1.16  1993/08/27  05:04:42  woo
+# Added <errno.h> to help.c and added support routines to binary.c
+#
+# Revision 3.50.1.15  1993/08/21  15:23:42  woo
+# Rewrote print_3dtable
+#
+# Revision 3.50.1.14  1993/08/19  04:10:23  woo
+# V. Broman sun_mgr driver
+#
+# Revision 3.50.1.13  1993/08/19  03:21:26  woo
+# R. Lang fix to MS-Windows print driver
+#
+# Revision 3.50.1.11  1993/08/10  03:55:03  woo
+# R. Lang mod to change location of plot in hppj.trm
+#
+# Revision 3.50.1.10  1993/08/07  16:06:34  woo
+# Fix using n bug, configure 1.3
+#
+# Revision 3.50.1.9  1993/08/05  05:38:59  woo
+# Fix timedate location for splot and plot + CONFIGURE ROUTINE
+#
+# Revision 3.50.1.8  1993/07/27  05:37:15  woo
+# More mods for SOLARIS 2.2 using gcc
+#
+# Revision 3.50.1.7  1993/07/27  04:57:58  woo
+# Fix impulse plot style if logscale y
+#
+# Revision 3.50.1.6  1993/07/27  03:35:12  woo
+# Fix epsviewe.m 
+#
+# Revision 3.50.1.4  1993/07/26  06:17:24  woo
+# Solaris mods to sun_x11 and gplt_x11.c
+#
+# Revision 3.50.1.3  1993/07/26  05:38:19  woo
+# DEC ALPHA OSF1 mods
+#
+# Revision 3.50.1.2  1993/07/26  05:12:42  woo
+# fix of replot of replot bug
+#
+# Revision 3.50.1.1  1993/07/26  04:59:54  woo
+# fix of splot notitle bug
+#
+# Revision 3.50  1993/07/09  05:35:24  woo
+# Baseline version 3.5 version
+#
+# Revision 3.38.2.153  1993/07/08  03:43:32  woo
+# Added dgrid3d save to misc.c and updated titlepages
+#
+# Revision 3.38.2.153  1993/07/08  03:43:32  woo
+# Added dgrid3d save to misc.c and updated titlepages
+#
+# Revision 3.38.2.152  1993/07/06  15:03:56  woo
+# A. Lehmann cleanup of 3_5b1
+#
+# Revision 3.38.2.151  1993/07/06  14:33:51  woo
+# New 0FAQ and AXPVMS fix to gplt_x11.c
+#
+# Revision 3.38.2.150  1993/07/02  16:42:43  woo
+# A. Reeh fix for monochrome X11 under VMS
+#
+# Revision 3.38.2.149  1993/07/01  20:31:55  woo
+# New version of GRASS makefile
+#
+# Revision 3.38.2.148  1993/07/01  13:54:25  woo
+# T. Collins changes to Latex line types
+#
+# Revision 3.38.2.147  1993/07/01  13:41:44  woo
+# A. Lehmann fix for hpux internal.c
+#
+# Revision 3.38.2.146  1993/06/30  21:24:08  woo
+# Fix to flash graphics, rosenbrock function in contours.dem
+#
+# Revision 3.38.2.145  1993/06/30  20:16:22  woo
+# Yehavi fixes for AXPVMS
+#
+# Revision 3.38.2.144  1993/06/23  00:34:39  woo
+# Reordered latex line types -- lighter default line
+#
+# Revision 3.38.2.143  1993/06/23  00:10:28  woo
+# R. Shouman fix of blank title induced linetype bug
+#
+# Revision 3.38.2.142  1993/06/21  14:43:21  woo
+# P. Egghart check on PLOSS for matherr and pass MY_FLAGS to subdirectories
+#
+# Revision 3.38.2.141  1993/06/19  13:00:21  woo
+# Okidata driver and time_t for sun386 mod
+#
+# Revision 3.38.2.140  1993/06/19  12:29:34  woo
+# J. Abbey fixes for Alliant
+#
+# Revision 3.38.2.139  1993/06/19  01:03:49  woo
+# Fix for 3d clipping bug
+#
+# Revision 3.38.2.138  1993/06/16  00:38:14  woo
+# O. Franksson MIF mod for vertical text and better char size
+#
+# Revision 3.38.2.137  1993/06/15  23:57:02  woo
+# Linux fixes
+#
+# Revision 3.38.2.136  1993/06/15  23:33:29  woo
+# V. Khera non-interactive stderr fix
+#
+# Revision 3.38.2.135  1993/06/15  22:02:26  woo
+# splot fix for x & y tics and labels
+#
 # Revision 3.38.2.134  1993/06/04  01:03:20  woo
 # Linux additions to makefile.unx
 #
@@ -593,3 +701,222 @@
 #
 ############################################################
 #
+RCSVER = 3.50.1.17
+RCSCOM = "V. Khera's fig patch"
+# List of source files
+# Used for making shar files, lint, and some dependencies.
+DIRS = term demo docs docs/latextut
+
+CSOURCE1 = bf_test.c binary.c command.c setshow.c
+CSOURCE2 = help.c gnubin.c graphics.c graph3d.c internal.c
+CSOURCE3 = misc.c eval.c parse.c plot.c readline.c scanner.c standard.c
+CSOURCE4 = bitmap.c term.c util.c version.c
+CSOURCE5 = term/ai.trm term/amiga.trm term/aed.trm term/atari.trm \
+	term/bigfig.trm term/cgi.trm term/corel.trm \
+	term/djsvga.trm term/dumb.trm \
+	term/dxf.trm term/dxy.trm term/debug.trm \
+	term/emxvga.trm term/eepic.trm term/epson.trm term/excl.trm \
+	term/fig.trm term/grass.trm term/hp26.trm term/hp2648.trm term/hpgl.trm \
+	term/hp500c.trm term/hpljii.trm term/metafont.trm term/mgr.trm\
+	term/apollo.trm term/gpr.trm term/hppj.trm term/compact.c
+CSOURCE6 = term/impcodes.h term/imagen.trm term/next.trm term/object.h \
+	term/iris4d.trm term/kyo.trm term/latex.trm term/mif.trm \
+	term/pbm.trm term/pslatex.trm term/gpic.trm term/gnugraph.trm
+CSOURCE7 = term/post.trm term/pstricks.trm term/qms.trm term/regis.trm \
+	term/rgip.trm term/sun.trm \
+	term/t410x.trm term/tek.trm term/texdraw.trm term/tgif.h \
+	term/tgif.trm term/tpic.trm \
+	term/unixpc.trm term/unixplot.trm \
+	term/v384.trm term/vws.trm term/x11.trm term/xlib.trm
+CSOURCE8 = contour.c specfun.c gplt_x11.c
+NEXTSRC  = epsviewe.m epsviewe.h
+# not C code, but still needed
+
+DEMOS = demo/1.dat demo/2.dat demo/3.dat demo/contours.dem \
+	demo/controls.dem demo/electron.dem demo/glass.dat demo/param.dem \
+	demo/polar.dem demo/simple.dem demo/surface1.dem \
+	demo/surface2.dem demo/using.dat demo/using.dem demo/world.cor \
+	demo/world.dat demo/world.dem \
+	demo/err.dat demo/poldat.dem demo/polar.dat demo/errorbar.dem \
+	demo/antenna.dat demo/all.dem demo/animate.dem demo/bivariat.dem \
+	demo/prob.dem demo/stat.inc demo/prob2.dem demo/random.dem \
+	demo/discrete.dem demo/hidden.dem demo/airfoil.dem demo/gnuplot.rot\
+	demo/binary.dem demo/spline.dem demo/steps.dem demo/steps.dat \
+	demo/multimsh.dem demo/whale.dat demo/hemisphr.dat \
+	demo/scatter.dem demo/scatter2.dat demo/singulr.dem demo/klein.dat 
+
+CONFIGURE = configure configure.in Makefile.in docs/Makefile.in\
+	docs/latextut/Makefile.in 0CONFIG
+
+ETC = Copyright 0README README.gnu README.ami makefile.unx makefile.vms \
+	linkopt.amg makefile.amg makefile.ami linkopt.vms buildvms.com \
+	lasergnu makefile.r makefile.nt makefile.g 0FAQ 0BUGS\
+	term/README History gnuplot.el intergra.x11 0INSTALL README.3p1\
+	README.3p2 README.3p3 README.3p4 README.pro README.nex README.x11 \
+	README.3d README.mf README.win README.iso README.3p5 README.pic \
+	README.xli $(CONFIGURE)
+
+#BETA files (not standard distribution files)
+BETA = 
+# PC-specific files
+PC = corgraph.asm corplot.c header.mac hrcgraph.asm lineproc.mac \
+	linkopt.msc makefile.msc makefile.tc makefile.st makefile.djg \
+	pcgraph.asm gnuplot.def makefile.286 makefile.emx \
+	makefile.ztc linkopt.ztc term/fg.trm term/pc.trm 
+WINDOWS = makefile.win makefile.msw README.win win/wcommon.h \
+	win/wgnuplib.c win/wgnuplib.def win/wgnuplib.h win/wgnuplib.rc \
+	win/wgnuplot.def win/wgnuplot.hpj win/wgnuplot.mnu win/wgnuplot.rc \
+	win/wgraph.c win/winmain.c win/wmenu.c win/wpause.c \
+	win/wprinter.c win/wresourc.h win/wtext.c win/wtext.h \
+	win/geticon.c docs/doc2rtf.c term/win.trm
+OS2 = makefile.os2 os2/makefile os2/dialogs.c os2/dialogs.h os2/gclient.c \
+	os2/gnuicon.uue os2/gnupmdrv.c os2/gnupmdrv.def os2/gnupmdrv.h \
+	os2/gnupmdrv.itl os2/gnupmdrv.rc os2/print.c docs/doc2ipf.c \
+	README.os2 term/pm.trm
+
+# Documentation and help files
+DOCS1 = docs/makefile docs/README docs/checkdoc.c docs/doc2gih.c \
+	docs/doc2hlp.c docs/doc2hlp.com docs/doc2ms.c docs/doc2tex.c \
+	docs/gnuplot.1 docs/lasergnu.1 docs/toc_entr.sty docs/doc2info.pl \
+	docs/titlepag.ms docs/titlepag.tex docs/makefile.ami \
+	docs/doc2rtf.c 
+DOCS2 = docs/gnuplot.doc docs/gpcard.tex
+DOCS3 = docs/latextut/makefile docs/latextut/eg1.plt \
+	docs/latextut/eg2.plt docs/latextut/eg3.dat docs/latextut/eg3.plt \
+	docs/latextut/eg4.plt docs/latextut/eg5.plt docs/latextut/eg6.plt \
+	docs/latextut/header.tex docs/latextut/tutorial.tex \
+	docs/latextut/linepoin.plt 
+
+#########################################################################
+################################################################
+# Miscellaneous targets
+
+SOURCES=plot.h help.h setshow.h bitmap.h term.h $(CSOURCE1) $(CSOURCE2) \
+	$(CSOURCE3) $(CSOURCE4) $(CSOURCE5) $(CSOURCE6) $(CSOURCE7)\
+	$(CSOURCE8) $(NEXTSRC) $(WINDOWS) $(OS2)
+
+DOCS  = $(DOCS1) $(DOCS2) $(DOCS3)
+
+lint:
+	lint -hx $(SOURCES)
+
+clean:
+	rm -f *.o *.orig *.rej *~ *.bak term/*~ term/*.orig term/*.bak
+	( cd docs; $(MAKE) $(MFLAGS) clean )
+	( cd docs/latextut; $(MAKE) $(MFLAGS) clean )
+
+spotless:
+	rm -f *.o *~ *.orig *.rej *.bak term/*~ term/*.orig term/*.bak \
+	TAGS gnuplot gnuplot_x11 \
+	bf_test demo/binary[1-3]
+	( cd docs; $(MAKE) $(MFLAGS) clean )
+	( cd docs/latextut; $(MAKE) $(MFLAGS) spotless )
+
+################################################################
+# Making shar files for mailing gnuplot
+
+shar: gnuplot.sh00 gnuplot.sh01 gnuplot.sh02 gnuplot.sh03 gnuplot.sh04 \
+	gnuplot.sh05 gnuplot.sh06 gnuplot.sh07 gnuplot.sh08 \
+	gnuplot.sh09 gnuplot.sh10 gnuplot.sh11 gnuplot.sh12 \
+	gnuplot.sh13 gnuplot.sh14 gnuplot.sh15 gnuplot.sh16
+
+gnuplot.sh00:
+	echo '#!/bin/sh' > gnuplot.sh00
+	echo '# This is a shell file to make directories' >> gnuplot.sh00
+	echo mkdir $(DIRS) >> gnuplot.sh00
+
+gnuplot.sh01: $(ETC)
+	shar $(ETC) > gnuplot.sh01
+
+gnuplot.sh02: $(DOCS1)
+	shar $(DOCS1) > gnuplot.sh02
+
+gnuplot.sh03: $(DOCS2)
+	shar $(DOCS2) > gnuplot.sh03
+
+gnuplot.sh04: $(DOCS3)
+	shar $(DOCS3) > gnuplot.sh04
+
+gnuplot.sh05: $(CSOURCE1)
+	shar $(CSOURCE1) > gnuplot.sh05
+
+gnuplot.sh06: $(CSOURCE2)
+	shar $(CSOURCE2) > gnuplot.sh06
+
+gnuplot.sh07: $(CSOURCE3)
+	shar $(CSOURCE3) > gnuplot.sh07
+
+gnuplot.sh08: $(CSOURCE4)
+	shar $(CSOURCE4) > gnuplot.sh08
+
+gnuplot.sh09: $(CSOURCE5)
+	shar $(CSOURCE5) > gnuplot.sh09
+
+gnuplot.sh10: $(CSOURCE6)
+	shar $(CSOURCE6) > gnuplot.sh10
+
+gnuplot.sh11: $(CSOURCE7)
+	shar $(CSOURCE7) > gnuplot.sh11
+
+gnuplot.sh12: $(PC)
+	shar $(PC) > gnuplot.sh12
+
+gnuplot.sh13: $(CSOURCE8)
+	shar $(CSOURCE8) > gnuplot.sh13
+
+gnuplot.sh14: $(DEMOS)
+	shar $(DEMOS) > gnuplot.sh14
+
+gnuplot.sh15: $(WINDOWS)
+	shar $(WINDOWS) > gnuplot.sh15
+
+gnuplot.sh16: $(BETA)
+	shar $(BETA) > gnuplot.sh16
+
+tar: $(ETC) $(SOURCES) $(PC) $(DEMOS) $(BETA) $(DOCS)
+	$(TAR) cvf /tmp/gnuplot.tar $(ETC) $(SOURCES) $(PC)\
+	     $(DEMOS) $(BETA) $(DOCS)
+#
+# the following uses Rick Saltz's makekit shar generation tools
+#
+
+kit: $(ETC) $(SOURCES) $(PC) $(DEMOS) $(BETA) $(DOCS)
+	makekit -s135k -k30 $(ETC) $(SOURCES) $(PC)\
+	     $(DEMOS) $(BETA) $(DOCS) MANIFEST
+
+branch: rcs rcsdoc rcsdemo
+
+rcs:
+	rcs -b$(RCSVER) $(ETC) $(SOURCES) $(PC)
+
+rcsdoc:
+	rcs -b$(RCSVER) $(DOCS)
+
+rcsdemo:
+	rcs -b$(RCSVER) $(DEMOS)
+
+ciall: ci cidocs cidemo
+
+ci:
+	ci -l$(RCSVER) -m$(RCSCOM) -t-$(RCSCOM) $(SOURCES) $(PC) $(ETC)
+
+cidocs:
+	ci -l$(RCSVER) -m$(RCSCOM) -t-$(RCSCOM) $(DOCS)
+
+cidemo:
+	ci -l$(RCSVER) -m$(RCSCOM) -t-$(RCSCOM) $(DEMOS)
+
+ciforce:
+	ci -f$(RCSVER) -m$(RCSCOM) -t-$(RCSCOM) $(SOURCES) $(ETC) $(DOCS) $(DEMOS) $(PC)
+
+coall: co codocs codemo
+
+co:
+	co -l -r$(RCSVER) $(ETC) $(SOURCES) $(PC)
+
+codocs:
+	co -l -r$(RCSVER) $(DOCS)
+
+codemo:
+	co -l -r$(RCSVER) $(DEMOS)
+
