@@ -1,4 +1,4 @@
-static char *RCSid = "$Id: setshow.c%v 3.38.2.127 1993/05/06 00:06:02 woo Exp woo $";
+static char *RCSid = "$Id: setshow.c%v 3.50.1.11 1993/08/10 03:55:03 woo Exp $";
 
 
 /* GNUPLOT - setshow.c */
@@ -196,7 +196,7 @@ struct arrow_def 	*first_arrow	= NULL;
 #else
 #if !defined(ATARI) && !defined (AMIGA_SC_6_1)
 extern char *strcpy(),*strcat();
-extern int strlen();
+extern int      strlen();
 #endif
 #endif
 
@@ -873,7 +873,8 @@ set_two()
 		   parametric = TRUE;
 		   strcpy (dummy_var[0], "t");
 		   strcpy (dummy_var[1], "y");
-	  	   (void) fprintf(stderr,"\n\tdummy variable is t for curves, u/v for surfaces\n");
+		   if (interactive)
+		     (void) fprintf(stderr,"\n\tdummy variable is t for curves, u/v for surfaces\n");
 	    }
 	    c_token++;
 	}
@@ -882,7 +883,8 @@ set_two()
 		   parametric = FALSE;
 		   strcpy (dummy_var[0], "x");
 		   strcpy (dummy_var[1], "y");
-	  	   (void) fprintf(stderr,"\n\tdummy variable is x for curves, x/y for surfaces\n");
+		   if (interactive)
+		     (void) fprintf(stderr,"\n\tdummy variable is x for curves, x/y for surfaces\n");
 	    }
 	    c_token++;
 	}
@@ -3005,6 +3007,7 @@ extern char patchlevel[];
 extern char date[];
 extern char copyright[];
 extern char bug_email[];
+extern char help_email[];
 int x;
 long time();
 
@@ -3014,5 +3017,6 @@ long time();
 	fprintf(stderr,"\tpatchlevel %s\n",patchlevel);
      fprintf(stderr, "\tlast modified %s\n", date);
 	fprintf(stderr,"\n\t%s   %s, %s\n", copyright,authors[x],authors[1-x]);
-    fprintf(stderr, "\n\tSend bugs and comments to %s\n", bug_email);
+    fprintf(stderr, "\n\tSend comments and requests for help to %s", help_email);
+    fprintf(stderr, "\n\tSend bugs, suggestions and mods to %s\n", bug_email);
 }
